@@ -1,7 +1,7 @@
 import cupy as cp
 import torch
 
-@cp.util.memoize(for_each_device=True)
+@cp.memoize(for_each_device=True)
 def cunnex(func_name, func_body):
   return cp.cuda.compile_with_cache(func_body).get_function(func_name)
   # return cp.cuda.compile_with_cache(globals()[strFunction]).get_function(strFunction)
@@ -41,4 +41,4 @@ class CustomKernel:
     )
     if max_dynamic_smem:
       fn.max_dynamic_shared_size_bytes = max_dynamic_smem
-    return fn
\ No newline at end of file
+    return fn
